package database

import "time"

// GetLastUsedPic
func (db *Database) GetCounterFor(key string) (time.Time, error) {
	var id int64
	var timestamp time.Time

	row, err := db.db.Query("SELECT `id`, `timestamp` FROM `counter` WHERE `key` = ? LIMIT 1", key)
	if err != nil {
		return timestamp, err
	}

	defer row.Close()
	for row.Next() {
		row.Scan(&id, &timestamp)
	}

	return timestamp, nil
}

// UpdateCounterFor - Add counter
func (db *Database) UpdateCounterFor(key string, timestamp time.Time) (int64, error) {
	exec, err := db.db.Exec(
		"REPLACE INTO `counter` (`key`, `timestamp`) VALUES (?,?)",
		key,
		timestamp,
	)

	if err != nil {
		return 0, err
	}

	return exec.LastInsertId()
}

// GetAllCounters
func (db *Database) GetAllCounters() (map[string]time.Time, error) {
	counters := make(map[string]time.Time)
	row, err := db.db.Query("SELECT id, timestamp FROM counter order by key ASC")
	if err != nil {
		return counters, err
	}

	defer row.Close()
	for row.Next() {
		var key string
		var timestamp time.Time
		row.Scan(&key, &timestamp)
		counters[key] = timestamp
	}

	return counters, nil
}
